pygeodesy.auxilats.auxLat

Package pygeodesy :: Package auxilats :: Module auxLat |
[frames] | no frames]

# Module auxLat

Class AuxLat transcoded to Python from Karney's C++ class AuxLatitude in GeographicLib version 2.2+.

Copyright (C) Charles Karney (2022-2024) and licensed under the MIT/X11 License. For more information, see the GeographicLib documentation.

See Also: Auxiliary latitudes On auxiliary latitudes.

Version: 26.01.20

Classes
| AuxLat Base class for accurate conversion between Auxiliary latitudes on an ellipsoid.